@@ -1,5 +1,5 @@
 from .attachments import Attachment, Color, Field
-from .blocks import ActionsBlock, ContextBlock, DividerBlock, FileBlock, ImageBlock, SectionBlock
+from .blocks import ActionsBlock, ContextBlock, DividerBlock, FileBlock, ImageBlock, SectionBlock, HeaderBlock
 from .elements import Button, Confirm, Element, Image, Text, TextType
 from .messages import Message
 
